/*****************************************************************************
 * Copyright (C) 2014-2018
 *
 * Michiel Broek <mbroek at mbse dot eu>
 *
 * This file is part of BrewCloud
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * BrewCloud is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ThermFerm; see the file COPYING.  If not, write to the Free
 * Software Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *****************************************************************************/


function createDelElements() {
	$('#eventWindow').jqxWindow({
		theme: theme,
		position: { x: 490, y: 210 },
		width: 300,
		height: 175,
		resizable: false,
		isModal: true,
		modalOpacity: 0.4,
		okButton: $('#delOk'),
		cancelButton: $('#delCancel'),
		initContent: function () {
			$('#delOk').jqxButton({ width: '65px', theme: theme });
			$('#delCancel').jqxButton({ width: '65px', theme: theme });
			$('#delCancel').focus();
		}
	});
	$('#eventWindow').jqxWindow('hide');
}


$(document).ready(function () {
	var url = "includes/db_inventory_mash_profiles.php";
	// prepare the data
	var source = {
		datatype: "json",
		cache: false,
		datafields: [
			{ name: 'record', type: 'number' },
			{ name: 'name', type: 'string' },
			{ name: 'notes', type: 'string' },
			{ name: 'steps', type: 'array' }
	//		{ name: 'step_name', type: 'string', map: 'steps>step_name' },
	//		{ name: 'step_type', type: 'string', map: 'steps>step_type' },
	//		{ name: 'step_temp', type: 'float', map: 'steps>step_temp' },
	//		{ name: 'step_time', type: 'float', map: 'steps>step_time' },
	//		{ name: 'tamp_time', type: 'float', map: 'steps>ramp_time' },
	//		{ name: 'end_temp', type: 'float', map: 'steps>end_temp' }
		],
		id: 'record',
		url: url,
		deleterow: function (rowid, commit) {
			// synchronize with the server - send delete command
			var data = "delete=true&" + $.param({ record: rowid });
			$.ajax({
				dataType: 'json',
				url: url,
				cache: false,
				data: data,
				success: function (data, status, xhr) {
					// delete command is executed.
					commit(true);
				},
				error: function (jqXHR, textStatus, errorThrown) {
					commit(false);
				}
			});
		},
		addrow: function (rowid, rowdata, position, commit) {
			var data = "insert=true&" + $.param(rowdata);
			$.ajax({
				dataType: 'json',
				url: url,
				cache: false,
				data: data,
				success: function (data, status, xhr) {
					commit(true);
				},
				error: function(jqXHR, textStatus, errorThrown) {
                                        commit(false);
                                }
                        });
                },
		updaterow: function (rowid, rowdata, commit) {
			var data = "update=true&" + $.param(rowdata);
			$.ajax({
				dataType: 'json',
				url: url,
				cache: false,
				data: data,
				success: function (data, status, xhr) {
					// update command is executed.
					commit(true);
				},
				error: function(jqXHR, textStatus, errorThrown) {
					commit(false);
				}
			});
		}
	};
	var dataAdapter = new $.jqx.dataAdapter(source);

	var editsteps = function (data) {
		var generaterow = function () {
			var row = {};
			row["step_name"] = "Stap 1";
			row["step_type"] = "Infusion";
			row["step_temp"] = 62.0;
			row['step_time'] = 20.0;
			row['ramp_time'] = 1.0;
			row['end_temp'] = 62.0;
			return row;
		}
		var stepSource = {
			localdata: data.steps,
			datatype: "local",
			datafields: [
				{ name: 'step_name', type: 'string' },
				{ name: 'step_type', type: 'string' },
				{ name: 'step_temp', type: 'float' },
				{ name: 'step_time', type: 'float' },
				{ name: 'ramp_time', type: 'float' },
				{ name: 'end_temp', type: 'float' }
			],
			addrow: function (rowid, rowdata, position, commit) {
				// synchronize with the server - send insert command
				// call commit with parameter true if the synchronization with the server is successful 
				//and with parameter false if the synchronization failed.
				// you can pass additional argument to the commit callback which represents the new ID if it is generated from a DB.
				commit(true);
			},
			deleterow: function (rowid, commit) {
				// synchronize with the server - send delete command
				// call commit with parameter true if the synchronization with the server is successful 
				//and with parameter false if the synchronization failed.
				commit(true);
			},
			updaterow: function (rowid, newdata, commit) {
				// synchronize with the server - send update command
				// call commit with parameter true if the synchronization with the server is successful 
				// and with parameter false if the synchronization failed.
				commit(true);
			}
		};
		var stepAdapter = new $.jqx.dataAdapter(stepSource);
		$("#grid").jqxGrid({
			width: 640,
			height: 330,
			source: stepAdapter,
			theme: theme,
			showtoolbar: true,
			rendertoolbar: function (toolbar) {
				var me = this;
				var container = $("<div style='margin: 5px;'></div>");
				toolbar.append(container);
				container.append('<input id="addrowbutton" type="button" value="Add New Row" />');
				container.append('<input style="margin-left: 5px;" id="deleterowbutton" type="button" value="Delete Selected Row" />');
				container.append('<input style="margin-left: 5px;" id="updaterowbutton" type="button" value="Update Selected Row" />');
				$("#addrowbutton").jqxButton({ theme: theme });
				$("#deleterowbutton").jqxButton({ theme: theme });
				$("#updaterowbutton").jqxButton({ theme: theme });
				// update row.
				$("#updaterowbutton").on('click', function () {
					var datarow = generaterow();
					var selectedrowindex = $("#grid").jqxGrid('getselectedrowindex');
					var rowscount = $("#grid").jqxGrid('getdatainformation').rowscount;
					if (selectedrowindex >= 0 && selectedrowindex < rowscount) {
						var id = $("#grid").jqxGrid('getrowid', selectedrowindex);
						var commit = $("#grid").jqxGrid('updaterow', id, datarow);
						$("#grid").jqxGrid('ensurerowvisible', selectedrowindex);
					}
				});
				// create new row.
				$("#addrowbutton").on('click', function () {
					var datarow = generaterow();
					var commit = $("#grid").jqxGrid('addrow', null, datarow);
				});
				// delete row.
				$("#deleterowbutton").on('click', function () {
					var selectedrowindex = $("#grid").jqxGrid('getselectedrowindex');
					var rowscount = $("#grid").jqxGrid('getdatainformation').rowscount;
					if (selectedrowindex >= 0 && selectedrowindex < rowscount) {
						var id = $("#grid").jqxGrid('getrowid', selectedrowindex);
						var commit = $("#grid").jqxGrid('deleterow', id);
					}
				});
			},
			columns: [
				{ text: 'Stap naam', datafield: 'step_name' },
				{ text: 'Stap type', datafield: 'step_type', width: 100 },
				{ text: 'Temperatuur', datafield: 'step_temp', width: 70, align: 'right', cellsalign: 'right', cellsformat: 'f1' },
				{ text: 'Eind', datafield: 'end_temp', width: 70, align: 'right', cellsalign: 'right', cellsformat: 'f1' },
				{ text: 'Tijd', datafield: 'step_time', width: 70, align: 'right', cellsalign: 'right' },
				{ text: 'Stap', datafield: 'ramp_time', width: 70, align: 'right', cellsalign: 'right' }
			]
		});
	};

	// initialize the input fields.
	$("#name").jqxInput({ theme: theme, width: 250, height: 23 });
	$("#notes").jqxInput({ theme: theme, width: 640, height: 100 });
	var editrow = -1;
	// initialize jqxGrid
	$("#jqxgrid").jqxGrid({
		width: 1280,
		height: 630,
		source: dataAdapter,
		theme: theme,
		showstatusbar: true,
		localization: getLocalization(),
		renderstatusbar: function (statusbar) {
			var container = $("<div style='overflow: hidden; position: relative; margin: 5px;'></div>");
			var addButton = $("<div style='float: right; margin-right: 15px;'><img style='position: relative; margin-top: 2px;' src='images/add.png'/><span style='margin-left: 4px; position: relative; top: -3px;'>Add</span></div>");
			container.append(addButton);
			statusbar.append(container);
			addButton.jqxButton({ theme: theme, width: 120, height: 20 });
			// add new row.
			addButton.click(function (event) {
				editrow = -1;
				$("#popupWindow").jqxWindow({ position: { x: 230, y: 30 } });
				$("#name").val('');
				$("#notes").val('');
				editsteps('');
				$("#popupWindow").jqxWindow('open');
			});
		},
		filterable: true,
		filtermode: 'excel',
		columns: [
			{ text: 'Maish schema', datafield: 'name', width: 250 },
			{ text: 'Opmerkingen', datafield: 'notes' },
			{ text: 'Wijzig', datafield: 'Edit', width: 120, align: 'center', columntype: 'button', cellsrenderer: function () {
				return "Wijzig";
				}, buttonclick: function (row) {
					// open the popup window when the user clicks a button.
					editrow = row;
					$("#popupWindow").jqxWindow({ position: { x: 230, y: 30 } });
					// get the clicked row's data and initialize the input fields.
					var dataRecord = $("#jqxgrid").jqxGrid('getrowdata', editrow);
					$("#name").val(dataRecord.name);
					$("#notes").val(dataRecord.notes);
					editsteps(dataRecord);
					// show the popup window.
					$("#popupWindow").jqxWindow('open');
				}
			}
		]
	});
	// initialize the popup window and buttons.
	$("#popupWindow").jqxWindow({
		width: 860,
		height: 550,
		resizable: false,
		theme: theme,
		isModal: true,
		autoOpen: false,
		cancelButton: $("#Cancel"),
		modalOpacity: 0.40
	});
	$("#popupWindow").on('open', function () {
		$("#name").jqxInput('selectAll');
	});
	$("#Delete").jqxButton({ theme: theme });
	$("#Delete").click(function () {
		if (editrow >= 0) {
			// Open a popup to confirm this action.
			$('#eventWindow').jqxWindow('open');
			$("#delOk").click(function () {
				var rowID = $('#jqxgrid').jqxGrid('getrowid', editrow);
				$("#jqxgrid").jqxGrid('deleterow', rowID);
			});
		}
		$("#popupWindow").jqxWindow('hide');
	});
	$("#Cancel").jqxButton({ theme: theme });
	$("#Save").jqxButton({ theme: theme });
	// update the edited row when the user clicks the 'Save' button.
	$("#Save").click(function () {
		if (editrow >= 0) {
			var rowID = $('#jqxgrid').jqxGrid('getrowid', editrow);
			var dataRecord = $("#jqxgrid").jqxGrid('getrowdata', editrow);
//	                                    $("#name").val(dataRecord.name);
			var row = {
				record: rowID,
				name: $("#name").val(),
				notes: $("#notes").val(),
				steps: dataRecord.steps
			};
			$('#jqxgrid').jqxGrid('updaterow', rowID, row);
			$("#popupWindow").jqxWindow('hide');
		} else {
			// Insert a record
			var newrow = {
				record: -1,
				name: $("#name").val(),
				notes: $("#notes").val()
			};
			$('#jqxgrid').jqxGrid('addrow', null, newrow);
			$("#popupWindow").jqxWindow('hide');
		}
	});
	createDelElements();
});

